@@ -1,3 +1,104 @@
+#' Evaluation of simulations results
+#' 
+#' Functions to compare model predictions against observed values.
+#' 
+#' @param out An object of class \code{\link{spwb}}, \code{\link{growth}} or \code{\link{pwb}}.
+#' @param measuredData A data frame with observed/measured values. Dates should be in row names, whereas columns should be named according to the type of output to be evaluated (see details).
+#' @param type A string with the kind of model output to be evaluated. Accepted values are \code{"SWC"} (soil moisture content), \code{"REW"} relative extractable water, \code{"ETR"} (total evapotranspiration), 
+#' \code{"SE+TR"} (modelled soil evaporation + transpiration against observed total evapotranspiration), \code{"E"} (transpiration per leaf area), \code{"LFMC"} (Live fuel moisture content), \code{"WP"} (plant water potentials), 
+#' \code{"BAI"} (basal area increment), \code{"DI"} (diameter increment), 
+#' \code{"DBH"} (diameter at breast height) or \code{"Height"} (plant height).
+#' @param cohort A string of the cohort to be compared (e.g. "T1_68"). If \code{NULL} results for the first cohort will be evaluated.
+#' @param temporalResolution A string to indicate the temporal resolution of the model evaluation, which can be "day", "week", "month" or "year". Observed and modelled values are aggregated temporally (using either means or sums) before comparison.
+#' @param plotType Plot type to draw, either \code{"dynamics"} or \code{"scatter"}.
+#' @param metric An evaluation metric:
+#'     \itemize{
+#'       \item{\code{"MAE"}: Mean absolute error.}
+#'       \item{\code{"MAE.rel"}: Mean absolute error in relative terms.}
+#'       \item{\code{"r"}: Pearson's linear correlation coefficient.}
+#'       \item{\code{"NSE"}: Nash-Sutcliffe model efficiency coefficient.}
+#'       \item{\code{"NSE.abs"}: Modified Nash-Sutcliffe model efficiency coefficient (L1 norm) (Legates & McCabe 1999).}
+#'       \item{\code{"loglikelihood"}: Logarithm of the likelihood of observing the data given the model predictions, assuming independent Gaussian errors.}
+#'     }
+#'
+#' @details Users should provide the appropriate columns in \code{measuredData}, depending on the type of output to be evaluated:
+#' \itemize{
+#'   \item{\code{"SWC" or "REW"}: A column named \code{"SWC"} should be present, containing soil moisture content in percent volume. When \code{type="REW"}, observed values are divided by the 90\% quantile, which is assumed to be the moisture content at field capacity.}
+#'   \item{\code{"ETR"} or \code{"SE+TR"}: A column named \code{"ETR"} should be present, containing stand's evapotranspiration in mm/day (or mm/week, mm/month, etc, depending on the temporal resolution). If \code{type="ETR"} observed values will be compared against modelled evapotranspiration (i.e. sum of transpiration, soil evaporation and interception loss), whereas if \code{type= "SE+TR"} observed values will be compared against the sum of transpiration and soil evaporation only.}
+#'   \item{\code{"E"}: For each plant cohort whose transpiration is to be evaluated, a column starting with \code{"E_"} and continuing with a cohort name (e.g. \code{"E_T1_68"}) with transpiration in L/m2/day on a leaf area basis (or L/m2/week, L/m2/month, etc, depending on the temporal resolution).}
+#'   \item{\code{"LFMC"}: For each plant cohort whose transpiration is to be evaluated, a column starting with \code{"FCM_"} and continuing with a cohort name (e.g. \code{"FMC_T1_68"}) with fuel moisture content as percent of dry weight.}
+#'   \item{\code{"WP"}: For each plant cohort whose transpiration is to be evaluated, two columns, one starting with \code{"PD_"} (for pre-dawn) and the other with \code{"MD_"} (for midday), and continuing with a cohort name (e.g. \code{"PD_T1_68"}). They should contain leaf water potential values in MPa. These are compared against sunlit water potentials.}
+#'   \item{\code{"BAI"}: For each plant cohort whose growth is to be evaluated, a column starting with \code{"BAI_"} and continuing with a cohort name (e.g. \code{"BAI_T1_68"}) with basal area increment in cm2/day, cm2/week, cm2/month or cm2/year, depending on the temporal resolution.}
+#'   \item{\code{"DI"}: For each plant cohort whose growth is to be evaluated, a column starting with \code{"DI_"} and continuing with a cohort name (e.g. \code{"DI_T1_68"}) with basal area increment in cm/day, cm/week, cm/month or cm/year, depending on the temporal resolution.}
+#'   \item{\code{"DBH"}: For each plant cohort whose growth is to be evaluated, a column starting with \code{"DBH_"} and continuing with a cohort name (e.g. \code{"DBH_T1_68"}) with DBH values in cm.}
+#'   \item{\code{"Height"}: For each plant cohort whose growth is to be evaluated, a column starting with \code{"Height_"} and continuing with a cohort name (e.g. \code{"Height_T1_68"}) with Height values in cm.}
+#' }
+#' Additional columns may exist with the standard error of measured quantities. These should be named as the referred quantity, followed by \code{"_err"} (e.g. \code{"PD_T1_68_err"}), and are used to draw confidence intervals around observations.
+#'  
+#' Row names in \code{measuredData} indicate the date of measurement (in the case of days). If measurements refer to months or years, row names should also be in a "year-month-day" format, although with "01" for days and/or months (e.g. "2001-02-01" for february 2001, or "2001-01-01" for year 2001).
+#'
+#' @return 
+#' \itemize{
+#'   \item{Function \code{evaluation_table} returns a data frame with dates, observed and predicted values.}
+#'   \item{Function \code{evaluation_stats} returns evaluation statistics (a vector or a data frame depending on \code{type}):
+#'     \itemize{
+#'       \item{\code{Bias}: Mean deviation (positive values correspond to model overestimations).}
+#'       \item{\code{Bias.rel}: Bias in relative terms (\%).}
+#'       \item{\code{MAE}: Mean absolute error.}
+#'       \item{\code{MAE.rel}: Mean absolute error in relative terms (\%).}
+#'       \item{\code{r}: Pearson's linear correlation coefficient.}
+#'       \item{\code{NSE}: Nash-Sutcliffe model efficiency coefficient.}
+#'       \item{\code{NSE.abs}: Modified Nash-Sutcliffe model efficiency coefficient (L1 norm) (Legates & McCabe 1999).}
+#'     }
+#'   }
+#'   \item{Function \code{evaluation_plot} returns a ggplot object.}
+#'   \item{Function \code{evaluation_metric} returns a scalar with the desired metric.}
+#' }
+#' 
+#' @author Miquel De \enc{Cáceres}{Caceres} Ainsa, CREAF
+#' 
+#' @references Legates, D.R., McCabe, G.J., 1999. Evaluating the use of “goodness-of-fit” measures in hydrologic and hydroclimatic model validation. Water Resour. Res. 35, 233–241.  
+#' 
+#' @seealso \code{\link{spwb}}, \code{\link{growth}}, \code{\link{optimization}}, \code{\link{exampleobs}}
+#' 
+#' @examples 
+#' #Load example daily meteorological data
+#' data(examplemeteo)
+#' 
+#' #Load example plot plant data
+#' data(exampleforestMED)
+#' 
+#' #Default species parameterization
+#' data(SpParamsMED)
+#' 
+#' #Initialize soil with default soil params (4 layers)
+#' examplesoil = soil(defaultSoilParams(4))
+#' 
+#' #Initialize control parameters
+#' control = defaultControl("Granier")
+#' 
+#' #Initialize input
+#' x1 = forest2spwbInput(exampleforestMED,examplesoil, SpParamsMED, control)
+#' 
+#' #Call simulation function
+#' S1<-spwb(x1, examplemeteo, latitude = 41.82592, elevation = 100)
+#' 
+#' #Load observed data (in this case the same simulation results with some added error)  
+#' data(exampleobs)
+#' 
+#' #Evaluation statistics for soil water content
+#' evaluation_stats(S1, exampleobs)
+#' 
+#' #NSE only
+#' evaluation_metric(S1, exampleobs, metric="NSE")
+#' 
+#' #Comparison of temporal dynamics
+#' evaluation_plot(S1, exampleobs)
+#' 
+#' #Loglikelihood value
+#' evaluation_metric(S1, exampleobs)
+#' 
+#' @name evaluation
 evaluation_table<-function(out, measuredData, type = "SWC", cohort = NULL, 
                            temporalResolution = "day") {
   
@@ -232,6 +333,7 @@ evaluation_table<-function(out, measuredData, type = "SWC", cohort = NULL,
   return(df)
 }
 
+#' @rdname evaluation
 evaluation_stats<-function(out, measuredData, type="SWC", cohort = NULL, 
                            temporalResolution = "day") {
   evalstats<-function(obs, pred) {
@@ -280,19 +382,20 @@ evaluation_stats<-function(out, measuredData, type="SWC", cohort = NULL,
   return(eval_res)
 }
 
+#' @rdname evaluation
 evaluation_plot<-function(out, measuredData, type="SWC", cohort = NULL, 
                           temporalResolution = "day",
                           plotType = "dynamics") {
   scatterplot<-function(df, xlab="", ylab="", title=NULL, err = FALSE) {
-    g<-ggplot(df, aes_string(x="Modelled"))
+    g<-ggplot(df, aes(x=.data$Modelled))
     if(err) {
       g<-g+
-        geom_pointrange(aes_string(y = "Observed", ymin = "obs_lower", ymax = "obs_upper"),cex=0.5)
+        geom_pointrange(aes(y = .data$Observed, ymin = .data$obs_lower, ymax = .data$obs_upper),cex=0.5)
     }
     g<-g + 
-      geom_point(aes_string(y = "Observed"), cex=0.5)+
+      geom_point(aes(y = .data$Observed), cex=0.5)+
       geom_abline(intercept=0, slope=1, col="black")+
-      geom_smooth(aes_string(y = "Observed"), method="lm", se = FALSE, col="gray", linetype="dashed")+
+      geom_smooth(aes(y = .data$Observed), method="lm", se = FALSE, col="gray", linetype="dashed")+
       xlab(xlab)+
       ylab(ylab)+
       theme_bw()
@@ -301,20 +404,20 @@ evaluation_plot<-function(out, measuredData, type="SWC", cohort = NULL,
   }
   dynamicsplot<-function(df, xlab="", ylab="", title=NULL, err = FALSE,
                          str_obs = "Observed", str_mod = "Modelled") {
-    g<-ggplot(df, aes_string(x="Dates"))
+    g<-ggplot(df, aes(x=.data$Dates))
     if(err) {
       g <- g +          
-        geom_ribbon(aes_(ymin=~obs_lower, ymax=~obs_upper), 
+        geom_ribbon(aes(ymin=.data$obs_lower, ymax=.data$obs_upper), 
                     col="gray", alpha= 0.5)
     }
     g<-g+       
-      geom_path(aes_(y=~Observed, col="Observed"))+
-      geom_path(aes_(y=~Modelled, col="Modelled"))+
+      geom_path(aes(y=.data$Observed, col="Observed"))+
+      geom_path(aes(y=.data$Modelled, col="Modelled"))+
       xlab(xlab)+
       ylab(ylab)+
       scale_color_manual(name="", 
                          values=c("Observed"="black", "Modelled"= "red"),
-                         labels =c(str_obs, str_mod))+
+                         labels =c("Observed"=str_obs, "Modelled"=str_mod))+
       theme_bw()
     if(!is.null(title)) g<-g+labs(title=title)
     return(g)
@@ -519,10 +622,10 @@ evaluation_plot<-function(out, measuredData, type="SWC", cohort = NULL,
     
     if(plotType=="dynamics"){
       g<-ggplot(df)+
-        geom_path(aes_(x=~Dates, y=~PD_mod, col="Predawn", linetype="Predawn"))+
-        geom_path(aes_(x=~Dates, y=~MD_mod, col="Midday", linetype="Midday"))+
-        geom_pointrange(aes_(x = ~Dates, y = ~PD_obs, ymin = ~PD_obs_lower, ymax = ~PD_obs_upper, col="Predawn", linetype="Predawn"))+
-        geom_pointrange(aes_(x = ~Dates, y = ~MD_obs, ymin = ~MD_obs_lower, ymax = ~MD_obs_upper, col="Midday",linetype="Midday"))+
+        geom_path(aes(x=.data$Dates, y=.data$PD_mod, col="Predawn", linetype="Predawn"))+
+        geom_path(aes(x=.data$Dates, y=.data$MD_mod, col="Midday", linetype="Midday"))+
+        geom_pointrange(aes(x = .data$Dates, y = .data$PD_obs, ymin = .data$PD_obs_lower, ymax = .data$PD_obs_upper, col="Predawn", linetype="Predawn"))+
+        geom_pointrange(aes(x = .data$Dates, y = .data$MD_obs, ymin = .data$MD_obs_lower, ymax = .data$MD_obs_upper, col="Midday",linetype="Midday"))+
         scale_color_manual(name="", values=c("Predawn"="blue", "Midday"= "red"))+
         scale_linetype_manual(name="", values=c("Predawn"="dashed", "Midday"= "solid"))+
         labs(title=paste0(cohort , " (",spnames[icoh],")"))+
@@ -532,10 +635,10 @@ evaluation_plot<-function(out, measuredData, type="SWC", cohort = NULL,
     } else {
       g<-ggplot(df)+
         geom_abline(intercept=0, slope=1, col="black")+
-        geom_pointrange(aes_(x = ~PD_mod, y = ~PD_obs, ymin = ~PD_obs_lower, ymax = ~PD_obs_upper, col="Predawn"))+
-        geom_pointrange(aes_(x = ~MD_mod, y = ~MD_obs, ymin = ~MD_obs_lower, ymax = ~MD_obs_upper,col="Midday"))+
-        geom_smooth(aes_(x = ~PD_mod, y = ~PD_obs, col="Predawn"), method="lm", se = FALSE, linetype="dashed")+
-        geom_smooth(aes_(x = ~MD_mod, y = ~MD_obs, col="Midday"), method="lm", se = FALSE, linetype="dashed")+
+        geom_pointrange(aes(x = .data$PD_mod, y = .data$PD_obs, ymin = .data$PD_obs_lower, ymax = .data$PD_obs_upper, col="Predawn"))+
+        geom_pointrange(aes(x = .data$MD_mod, y = .data$MD_obs, ymin = .data$MD_obs_lower, ymax = .data$MD_obs_upper,col="Midday"))+
+        geom_smooth(aes(x = .data$PD_mod, y = .data$PD_obs, col="Predawn"), method="lm", se = FALSE, linetype="dashed")+
+        geom_smooth(aes(x = .data$MD_mod, y = .data$MD_obs, col="Midday"), method="lm", se = FALSE, linetype="dashed")+
         scale_color_manual(name="", values=c("Predawn"="blue", "Midday"= "red"))+
         labs(title=paste0(cohort , " (",spnames[icoh],")"))+
         xlab("Modelled leaf water potential (MPa)")+
@@ -546,6 +649,7 @@ evaluation_plot<-function(out, measuredData, type="SWC", cohort = NULL,
   return(g)
 }
 
+#' @rdname evaluation
 evaluation_metric<-function(out, measuredData, type="SWC", cohort=NULL, 
                             temporalResolution = "day",
                             metric = "loglikelihood") {
